"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setHeaders = void 0;
/**
 * Set headers for response
 * @param response - expressjs `response` object or fastify `response.raw` object
 * @param limiterInfo - `LimiterInfo` object from `ratelimiter`
 */
function setHeaders(response, limiterInfo) {
    const prevRemaining = response.getHeader('X-RateLimit-Remaining');
    if (prevRemaining && parseInt(prevRemaining, 10) < limiterInfo.remaining)
        return;
    response.setHeader('X-RateLimit-Limit', limiterInfo.total);
    response.setHeader('X-RateLimit-Remaining', limiterInfo.remaining - 1);
    response.setHeader('X-RateLimit-Reset', limiterInfo.reset);
}
exports.setHeaders = setHeaders;
//# sourceMappingURL=set-headers.fn.js.map